@@ -28,13 +28,16 @@ Methods
 
 """
 
-from io import BytesIO
-from typing import Callable, Optional, Dict, Any, Tuple, cast, Iterator, Union, List
-import numpy as np
-from PIL import Image, UnidentifiedImageError, ImageSequence, ExifTags  # type: ignore
-from ..core.request import Request, IOMode, InitializationError, URI_BYTES
-from ..core.v3_plugin_api import PluginV3, ImageProperties
+import sys
 import warnings
+from io import BytesIO
+from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union, cast
+
+import numpy as np
+from PIL import ExifTags, Image, ImageSequence, UnidentifiedImageError  # type: ignore
+
+from ..core.request import URI_BYTES, InitializationError, IOMode, Request
+from ..core.v3_plugin_api import ImageProperties, PluginV3
 from ..typing import ArrayLike
 
 
@@ -203,7 +206,8 @@ class PillowPlugin(PluginV3):
         if as_gray is not None:
             raise TypeError(
                 "The keyword `as_gray` is no longer supported."
-                "Use `mode='L'` instead."
+                "Use `mode='F'` for a backward-compatible result, or "
+                " `mode='L'` for an integer-valued result."
             )
 
         if index is None:
@@ -275,6 +279,31 @@ class PillowPlugin(PluginV3):
             # adjust for pillow9 changes
             # see: https://github.com/python-pillow/Pillow/issues/5929
             image = image.convert(image.palette.mode)
+        elif image.format == "PNG" and image.mode == "I":
+            # By default, pillows unpacks 16-bit grayscale PNG into 32-bit
+            # integers due to limited 16-bit support in pillow itself. However,
+            # recent versions can directly unpack into a 16-bit buffer, which is
+            # more correct (and more efficient) in our scenario.
+
+            if sys.byteorder == "little":
+                desired_mode = "I;16"
+            else:  # pragma: no cover
+                # can't test big-endian in GH-Actions
+                desired_mode = "I;16B"
+
+            try:
+                Image._getdecoder(desired_mode, "raw", "I;16B")
+            except ValueError:
+                warnings.warn(
+                    "Loading 16-bit (uint16) PNG as int32 due to limitations "
+                    "in pillow's PNG decoder. This will be fixed in a future "
+                    "version of pillow which will make this warning dissapear.",
+                    UserWarning,
+                )
+            else:  # pragma: no cover
+                # Let pillow know that it is okay to return 16-bit
+                image.mode = desired_mode
+
         image = np.asarray(image)
 
         meta = self.metadata(index=self._image.tell(), exclude_applied=False)
