@@ -115,7 +115,9 @@ def test_png_16bit(test_images, tmp_path):
     im2 = iio.imread(tmp_path / "2.png", plugin="pillow")
     assert im2.dtype == np.uint8
 
-    im3 = iio.imread(tmp_path / "1.png", plugin="pillow")
+    with pytest.warns(UserWarning):
+        im3 = iio.imread(tmp_path / "1.png", plugin="pillow")
+
     assert im3.dtype == np.int32
 
 
@@ -603,8 +605,8 @@ def test_apng_metadata(tmp_path, test_images):
     assert metadata == metadata2
 
 
-def test_write_format_warning():
-    frames = iio.imread("imageio:chelsea.png")
+def test_write_format_warning(test_images):
+    frames = iio.imread(test_images / "chelsea.png")
     bytes_image = iio.imwrite("<bytes>", frames, extension=".png", plugin="pillow")
 
     with pytest.warns(UserWarning):
