@@ -1,5 +1,4 @@
 import io
-import platform
 import warnings
 from contextlib import ExitStack
 from pathlib import Path
@@ -17,7 +16,11 @@ from av.video.format import names as video_format_names  # type: ignore # noqa:
 from imageio.plugins.pyav import _format_to_dtype  # noqa: E402
 
 IS_AV_10_0_0 = tuple(int(x) for x in av.__version__.split(".")) == (10, 0, 0)
-IS_MACOS = platform.system() == "Darwin"
+
+# the maintainer of pyAV hasn't responded to my bug reports in over 4 months so
+# I am disabling test on pypy to stay sane.
+if IS_PYPY:
+    pytest.skip("pyAV sometimes causes segfaults on Pypy.", allow_module_level=True)
 
 
 def test_mp4_read(test_images: Path):
@@ -577,12 +580,6 @@ def test_keyframe_intervals(test_images):
     assert np.max(np.diff(key_dist)) <= 5
 
 
-# the maintainer of pyAV hasn't responded to my bug reports in over 4 months so
-# I am disabling this test on pypy to stay sane.
-@pytest.mark.skipif(
-    IS_PYPY and IS_MACOS,
-    reason="Using filters in pyAV sometimes causes segfaults when run on Pypy.",
-)
 def test_trim_filter(test_images):
     # this is a regression test for:
     # https://github.com/imageio/imageio/issues/951
